Exposing SPL standard toolkit as classes and installable package for the Python Application API for IBM Streams.

Latest documentation

* http://streamsxstandard.readthedocs.io

Package is organized using standard packaging to upload to PyPi.

* http://pypi.org/project/streamsx.standard/


```
pip install streamsx.standard
```

The latest code be installed as the `streamsx.standard` package directly from github using:

```
pip install git+https://github.com/IBMStreams/streamsx.standard.git
```
